[![Tests](https://img.shields.io/github/actions/workflow/status/kfields/cowsay-django/test.yml?label=Tests&style=for-the-badge)](https://github.com/kfields/cowsay-django/actions/workflows/test.yml)
[![Codecov](https://img.shields.io/codecov/c/github/kfields/cowsay-django?style=for-the-badge)](https://app.codecov.io/gh/kfields/cowsay-django)
[![PyPI](https://img.shields.io/pypi/v/cowsay-django.svg?style=for-the-badge&logo=appveyor)](https://pypi.org/project/cowsay-django/)

[![Pypi downloads](https://img.shields.io/pypi/dm/cowsay-django?style=for-the-badge)](https://pypistats.org/packages/cowsay-django)
[![Python versions](https://img.shields.io/pypi/pyversions/cowsay-django?style=social)](https://pypi.org/project/cowsay-django/)

# Cowsay Django

-----

**Table of Contents**

- [Cowsay Django](#cowsay-django)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install cowsay-django
```

## License

`cowsay-django` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
